info = {
    "name": "kk",
    "date_order": "DMY",
    "january": [
        "қаң",
        "қаңтар"
    ],
    "february": [
        "ақп",
        "ақпан"
    ],
    "march": [
        "нау",
        "наурыз"
    ],
    "april": [
        "сәу",
        "сәуір"
    ],
    "may": [
        "мам",
        "мамыр"
    ],
    "june": [
        "мау",
        "маусым"
    ],
    "july": [
        "шіл",
        "шілде"
    ],
    "august": [
        "там",
        "тамыз"
    ],
    "september": [
        "қыр",
        "қыркүйек"
    ],
    "october": [
        "қаз",
        "қазан"
    ],
    "november": [
        "қар",
        "қараша"
    ],
    "december": [
        "жел",
        "желтоқсан"
    ],
    "monday": [
        "дс",
        "дүйсенбі"
    ],
    "tuesday": [
        "сейсенбі",
        "сс"
    ],
    "wednesday": [
        "ср",
        "сәрсенбі"
    ],
    "thursday": [
        "бейсенбі",
        "бс"
    ],
    "friday": [
        "жм",
        "жұма"
    ],
    "saturday": [
        "сб",
        "сенбі"
    ],
    "sunday": [
        "жексенбі",
        "жс"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ж",
        "жыл"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "ап",
        "апта"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "сағ",
        "сағат"
    ],
    "minute": [
        "мин",
        "минут"
    ],
    "second": [
        "с",
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "бүгін"
        ],
        "0 hour ago": [
            "осы сағат"
        ],
        "0 minute ago": [
            "осы минут"
        ],
        "0 month ago": [
            "осы ай"
        ],
        "0 second ago": [
            "қазір"
        ],
        "0 week ago": [
            "осы апта"
        ],
        "0 year ago": [
            "биылғы жыл"
        ],
        "1 day ago": [
            "кеше"
        ],
        "1 month ago": [
            "өткен ай"
        ],
        "1 week ago": [
            "өткен апта"
        ],
        "1 year ago": [
            "былтырғы жыл"
        ],
        "in 1 day": [
            "ертең"
        ],
        "in 1 month": [
            "келесі ай"
        ],
        "in 1 week": [
            "келесі апта"
        ],
        "in 1 year": [
            "келесі жыл"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) күн бұрын"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) сағ бұрын",
            "(\\d+[.,]?\\d*) сағат бұрын"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) мин бұрын",
            "(\\d+[.,]?\\d*) минут бұрын"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ай бұрын"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) сек бұрын",
            "(\\d+[.,]?\\d*) секунд бұрын"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) ап бұрын",
            "(\\d+[.,]?\\d*) апта бұрын"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) ж бұрын",
            "(\\d+[.,]?\\d*) жыл бұрын"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) күннен кейін"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) сағ кейін",
            "(\\d+[.,]?\\d*) сағаттан кейін"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) мин кейін",
            "(\\d+[.,]?\\d*) минуттан кейін"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) айдан кейін"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) сек кейін",
            "(\\d+[.,]?\\d*) секундтан кейін"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) ап кейін",
            "(\\d+[.,]?\\d*) аптадан кейін"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) ж кейін",
            "(\\d+[.,]?\\d*) жылдан кейін"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
