info = {
    "name": "nd",
    "date_order": "DMY",
    "january": [
        "zib",
        "zibandlela"
    ],
    "february": [
        "nhlo",
        "nhlolanja"
    ],
    "march": [
        "mbi",
        "mbimbitho"
    ],
    "april": [
        "mab",
        "mabasa"
    ],
    "may": [
        "nkw",
        "nkwenkwezi"
    ],
    "june": [
        "nhla",
        "nhlangula"
    ],
    "july": [
        "ntu",
        "ntulikazi"
    ],
    "august": [
        "ncw",
        "ncwabakazi"
    ],
    "september": [
        "mpan",
        "mpandula"
    ],
    "october": [
        "mfu",
        "mfumfu"
    ],
    "november": [
        "lwe",
        "lwezi"
    ],
    "december": [
        "mpal",
        "mpalakazi"
    ],
    "monday": [
        "mvu",
        "mvulo"
    ],
    "tuesday": [
        "sib",
        "sibili"
    ],
    "wednesday": [
        "sit",
        "sithathu"
    ],
    "thursday": [
        "sin",
        "sine"
    ],
    "friday": [
        "sih",
        "sihlanu"
    ],
    "saturday": [
        "mgq",
        "mgqibelo"
    ],
    "sunday": [
        "son",
        "sonto"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "umnyaka"
    ],
    "month": [
        "inyangacale"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "ilanga"
    ],
    "hour": [
        "ihola"
    ],
    "minute": [
        "umuzuzu"
    ],
    "second": [
        "isekendi"
    ],
    "relative-type": {
        "0 day ago": [
            "lamuhla"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "izolo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
