info = {
    "name": "guz",
    "date_order": "DMY",
    "january": [
        "can",
        "chanuari"
    ],
    "february": [
        "feb",
        "feburari"
    ],
    "march": [
        "mac",
        "machi"
    ],
    "april": [
        "apiriri",
        "apr"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "chulai",
        "cul"
    ],
    "august": [
        "agosti",
        "agt"
    ],
    "september": [
        "sep",
        "septemba"
    ],
    "october": [
        "okitoba",
        "okt"
    ],
    "november": [
        "nob",
        "nobemba"
    ],
    "december": [
        "dis",
        "disemba"
    ],
    "monday": [
        "chumatato",
        "ctt"
    ],
    "tuesday": [
        "chumaine",
        "cmn"
    ],
    "wednesday": [
        "chumatano",
        "cmt"
    ],
    "thursday": [
        "aramisi",
        "ars"
    ],
    "friday": [
        "ichuma",
        "icm"
    ],
    "saturday": [
        "esabato",
        "est"
    ],
    "sunday": [
        "chumapiri",
        "cpr"
    ],
    "am": [
        "ma",
        "mambia"
    ],
    "pm": [
        "mo",
        "mog"
    ],
    "year": [
        "omwaka"
    ],
    "month": [
        "omotienyi"
    ],
    "week": [
        "omokubio"
    ],
    "day": [
        "rituko"
    ],
    "hour": [
        "ensa"
    ],
    "minute": [
        "edakika"
    ],
    "second": [
        "esekendi"
    ],
    "relative-type": {
        "0 day ago": [
            "rero"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "igoro"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "mambia"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
