info = {
    "name": "ug",
    "date_order": "YMD",
    "january": [
        "يانۋار"
    ],
    "february": [
        "فېۋرال"
    ],
    "march": [
        "مارت"
    ],
    "april": [
        "ئاپرېل"
    ],
    "may": [
        "ماي"
    ],
    "june": [
        "ئىيۇن"
    ],
    "july": [
        "ئىيۇل"
    ],
    "august": [
        "ئاۋغۇست"
    ],
    "september": [
        "سېنتەبىر"
    ],
    "october": [
        "ئۆكتەبىر"
    ],
    "november": [
        "نويابىر"
    ],
    "december": [
        "دېكابىر"
    ],
    "monday": [
        "دۈ",
        "دۈشەنبە"
    ],
    "tuesday": [
        "سە",
        "سەيشەنبە"
    ],
    "wednesday": [
        "چا",
        "چارشەنبە"
    ],
    "thursday": [
        "پە",
        "پەيشەنبە"
    ],
    "friday": [
        "جۈ",
        "جۈمە"
    ],
    "saturday": [
        "شە",
        "شەنبە"
    ],
    "sunday": [
        "يە",
        "يەكشەنبە"
    ],
    "am": [
        "چب",
        "چۈشتىن بۇرۇن"
    ],
    "pm": [
        "چك",
        "چۈشتىن كېيىن"
    ],
    "year": [
        "يىل"
    ],
    "month": [
        "ئاي"
    ],
    "week": [
        "ھەپتە"
    ],
    "day": [
        "كۈن"
    ],
    "hour": [
        "سائەت"
    ],
    "minute": [
        "مىنۇت"
    ],
    "second": [
        "سېكۇنت"
    ],
    "relative-type": {
        "0 day ago": [
            "بۈگۈن"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "بۇ ئاي"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "بۇ ھەپتە"
        ],
        "0 year ago": [
            "بۇ يىل"
        ],
        "1 day ago": [
            "تۈنۈگۈن"
        ],
        "1 month ago": [
            "ئۆتكەن ئاي"
        ],
        "1 week ago": [
            "ئۆتكەن ھەپتە"
        ],
        "1 year ago": [
            "ئۆتكەن يىل"
        ],
        "in 1 day": [
            "ئەتە"
        ],
        "in 1 month": [
            "كېلەر ئاي"
        ],
        "in 1 week": [
            "كېلەر ھەپتە"
        ],
        "in 1 year": [
            "كېلەر يىل"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) كۈن ئىلگىرى"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) سائەت ئىلگىرى"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) مىنۇت ئىلگىرى"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ئاي ئىلگىرى"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) سېكۇنت ئىلگىرى"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) ھەپتە ئىلگىرى"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) يىل ئىلگىرى"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) كۈندىن كېيىن"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) سائەتتىن كېيىن"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) مىنۇتتىن كېيىن"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ئايدىن كېيىن"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) سېكۇنتتىن كېيىن"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) ھەپتىدىن كېيىن"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) يىلدىن كېيىن"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
