info = {
    "name": "mfe",
    "date_order": "DMY",
    "january": [
        "zan",
        "zanvie"
    ],
    "february": [
        "fev",
        "fevriye"
    ],
    "march": [
        "mar",
        "mars"
    ],
    "april": [
        "avr",
        "avril"
    ],
    "may": [
        "me"
    ],
    "june": [
        "zin"
    ],
    "july": [
        "zil",
        "zilye"
    ],
    "august": [
        "out"
    ],
    "september": [
        "sep",
        "septam"
    ],
    "october": [
        "okt",
        "oktob"
    ],
    "november": [
        "nov",
        "novam"
    ],
    "december": [
        "des",
        "desam"
    ],
    "monday": [
        "lin",
        "lindi"
    ],
    "tuesday": [
        "mar",
        "mardi"
    ],
    "wednesday": [
        "mer",
        "merkredi"
    ],
    "thursday": [
        "ze",
        "zedi"
    ],
    "friday": [
        "van",
        "vandredi"
    ],
    "saturday": [
        "sam",
        "samdi"
    ],
    "sunday": [
        "dim",
        "dimans"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "lane"
    ],
    "month": [
        "mwa"
    ],
    "week": [
        "semenn"
    ],
    "day": [
        "zour"
    ],
    "hour": [
        "ler"
    ],
    "minute": [
        "minit"
    ],
    "second": [
        "segonn"
    ],
    "relative-type": {
        "0 day ago": [
            "zordi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yer"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "demin"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
