info = {
    "name": "dyo",
    "date_order": "DMY",
    "january": [
        "sa",
        "sanvie"
    ],
    "february": [
        "fe",
        "fébirie"
    ],
    "march": [
        "ma",
        "mars"
    ],
    "april": [
        "ab",
        "aburil"
    ],
    "may": [
        "me",
        "mee"
    ],
    "june": [
        "su",
        "sueŋ"
    ],
    "july": [
        "sú",
        "súuyee"
    ],
    "august": [
        "ut"
    ],
    "september": [
        "se",
        "settembar"
    ],
    "october": [
        "ok",
        "oktobar"
    ],
    "november": [
        "no",
        "novembar"
    ],
    "december": [
        "de",
        "disambar"
    ],
    "monday": [
        "ten",
        "teneŋ"
    ],
    "tuesday": [
        "tal",
        "talata"
    ],
    "wednesday": [
        "ala",
        "alarbay"
    ],
    "thursday": [
        "ara",
        "aramisay"
    ],
    "friday": [
        "arj",
        "arjuma"
    ],
    "saturday": [
        "sib",
        "sibiti"
    ],
    "sunday": [
        "dim",
        "dimas"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "emit"
    ],
    "month": [
        "fuleeŋ"
    ],
    "week": [
        "lóokuŋ"
    ],
    "day": [
        "funak"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "jaat"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "fucen"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kajom"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
