info = {
    "name": "ln",
    "date_order": "DMY",
    "january": [
        "sánzá ya yambo",
        "yan"
    ],
    "february": [
        "fbl",
        "sánzá ya míbalé"
    ],
    "march": [
        "msi",
        "sánzá ya mísáto"
    ],
    "april": [
        "apl",
        "sánzá ya mínei"
    ],
    "may": [
        "mai",
        "sánzá ya mítáno"
    ],
    "june": [
        "sánzá ya motóbá",
        "yun"
    ],
    "july": [
        "sánzá ya nsambo",
        "yul"
    ],
    "august": [
        "agt",
        "sánzá ya mwambe"
    ],
    "september": [
        "stb",
        "sánzá ya libwa"
    ],
    "october": [
        "sánzá ya zómi",
        "ɔtb"
    ],
    "november": [
        "nvb",
        "sánzá ya zómi na mɔ̌kɔ́"
    ],
    "december": [
        "dsb",
        "sánzá ya zómi na míbalé"
    ],
    "monday": [
        "mokɔlɔ mwa yambo",
        "ybo"
    ],
    "tuesday": [
        "mbl",
        "mokɔlɔ mwa míbalé"
    ],
    "wednesday": [
        "mokɔlɔ mwa mísáto",
        "mst"
    ],
    "thursday": [
        "min",
        "mokɔlɔ ya mínéi"
    ],
    "friday": [
        "mokɔlɔ ya mítáno",
        "mtn"
    ],
    "saturday": [
        "mps",
        "mpɔ́sɔ"
    ],
    "sunday": [
        "eye",
        "eyenga"
    ],
    "am": [
        "ntɔ́ngɔ́"
    ],
    "pm": [
        "mpókwa"
    ],
    "year": [
        "mobú"
    ],
    "month": [
        "sánzá"
    ],
    "week": [
        "pɔ́sɔ"
    ],
    "day": [
        "mokɔlɔ"
    ],
    "hour": [
        "ngonga"
    ],
    "minute": [
        "monúti"
    ],
    "second": [
        "sɛkɔ́ndɛ"
    ],
    "relative-type": {
        "0 day ago": [
            "lɛlɔ́"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "lóbi elékí"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "lóbi ekoyâ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "ln-AO": {
            "name": "ln-AO"
        },
        "ln-CF": {
            "name": "ln-CF"
        },
        "ln-CG": {
            "name": "ln-CG"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
