info = {
    "name": "ak",
    "date_order": "YMD",
    "january": [
        "s-ɔ",
        "sanda-ɔpɛpɔn"
    ],
    "february": [
        "k-ɔ",
        "kwakwar-ɔgyefuo"
    ],
    "march": [
        "e-ɔ",
        "ebɔw-ɔbenem"
    ],
    "april": [
        "e-o",
        "ebɔbira-oforisuo"
    ],
    "may": [
        "e-k",
        "esusow aketseaba-kɔtɔnimba"
    ],
    "june": [
        "o-a",
        "obirade-ayɛwohomumu"
    ],
    "july": [
        "a-k",
        "ayɛwoho-kitawonsa"
    ],
    "august": [
        "d-ɔ",
        "difuu-ɔsandaa"
    ],
    "september": [
        "f-ɛ",
        "fankwa-ɛbɔ"
    ],
    "october": [
        "ɔ-a",
        "ɔbɛsɛ-ahinime"
    ],
    "november": [
        "ɔ-o",
        "ɔberɛfɛw-obubuo"
    ],
    "december": [
        "m-ɔ",
        "mumu-ɔpɛnimba"
    ],
    "monday": [
        "dwo",
        "dwowda"
    ],
    "tuesday": [
        "ben",
        "benada"
    ],
    "wednesday": [
        "wuk",
        "wukuda"
    ],
    "thursday": [
        "yaw",
        "yawda"
    ],
    "friday": [
        "fia",
        "fida"
    ],
    "saturday": [
        "mem",
        "memeneda"
    ],
    "sunday": [
        "kwe",
        "kwesida"
    ],
    "am": [
        "an"
    ],
    "pm": [
        "ew"
    ],
    "year": [
        "afe"
    ],
    "month": [
        "bosome"
    ],
    "week": [
        "dapɛn"
    ],
    "day": [
        "da"
    ],
    "hour": [
        "dɔnhwer"
    ],
    "minute": [
        "sema"
    ],
    "second": [
        "sɛkɛnd"
    ],
    "relative-type": {
        "0 day ago": [
            "ndɛ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ndeda"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ɔkyena"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
