info = {
    "name": "om",
    "date_order": "DMY",
    "january": [
        "ama",
        "amajjii"
    ],
    "february": [
        "gur",
        "guraandhala"
    ],
    "march": [
        "bit",
        "bitooteessa"
    ],
    "april": [
        "elb",
        "elba"
    ],
    "may": [
        "caamsa",
        "cam"
    ],
    "june": [
        "wax",
        "waxabajjii"
    ],
    "july": [
        "ado",
        "adooleessa"
    ],
    "august": [
        "hag",
        "hagayya"
    ],
    "september": [
        "ful",
        "fuulbana"
    ],
    "october": [
        "onk",
        "onkololeessa"
    ],
    "november": [
        "sad",
        "sadaasa"
    ],
    "december": [
        "mud",
        "muddee"
    ],
    "monday": [
        "wiixata",
        "wix"
    ],
    "tuesday": [
        "qib",
        "qibxata"
    ],
    "wednesday": [
        "rob",
        "roobii"
    ],
    "thursday": [
        "kam",
        "kamiisa"
    ],
    "friday": [
        "jim",
        "jimaata"
    ],
    "saturday": [
        "san",
        "sanbata"
    ],
    "sunday": [
        "dil",
        "dilbata"
    ],
    "am": [
        "wd"
    ],
    "pm": [
        "wb"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "om-KE": {
            "name": "om-KE"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
