info = {
    "name": "nn",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar"
    ],
    "february": [
        "feb",
        "februar"
    ],
    "march": [
        "mar",
        "mars"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "juli"
    ],
    "august": [
        "aug",
        "august"
    ],
    "september": [
        "sep",
        "september"
    ],
    "october": [
        "okt",
        "oktober"
    ],
    "november": [
        "nov",
        "november"
    ],
    "december": [
        "des",
        "desember"
    ],
    "monday": [
        "må",
        "mån",
        "måndag"
    ],
    "tuesday": [
        "ty",
        "tys",
        "tysdag"
    ],
    "wednesday": [
        "on",
        "ons",
        "onsdag"
    ],
    "thursday": [
        "to",
        "tor",
        "torsdag"
    ],
    "friday": [
        "fr",
        "fre",
        "fredag"
    ],
    "saturday": [
        "la",
        "lau",
        "laurdag"
    ],
    "sunday": [
        "sø",
        "søn",
        "søndag"
    ],
    "am": [
        "fm",
        "formiddag"
    ],
    "pm": [
        "em",
        "ettermiddag"
    ],
    "year": [
        "år"
    ],
    "month": [
        "månad"
    ],
    "week": [
        "veke"
    ],
    "day": [
        "dag"
    ],
    "hour": [
        "time"
    ],
    "minute": [
        "minutt"
    ],
    "second": [
        "sekund"
    ],
    "relative-type": {
        "0 day ago": [
            "i dag"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "i går"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "i morgon"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "for (\\d+[.,]?\\d*) døgn siden"
        ],
        "\\1 hour ago": [
            "for (\\d+[.,]?\\d*) time siden",
            "for (\\d+[.,]?\\d*) timer siden"
        ],
        "\\1 minute ago": [
            "for (\\d+[.,]?\\d*) minutt siden",
            "for (\\d+[.,]?\\d*) minutter siden"
        ],
        "\\1 month ago": [
            "for (\\d+[.,]?\\d*) måned siden",
            "for (\\d+[.,]?\\d*) måneder siden"
        ],
        "\\1 second ago": [
            "for (\\d+[.,]?\\d*) sekund siden",
            "for (\\d+[.,]?\\d*) sekunder siden"
        ],
        "\\1 week ago": [
            "for (\\d+[.,]?\\d*) uke siden",
            "for (\\d+[.,]?\\d*) uker siden"
        ],
        "\\1 year ago": [
            "for (\\d+[.,]?\\d*) år siden"
        ],
        "in \\1 day": [
            "om (\\d+[.,]?\\d*) døgn"
        ],
        "in \\1 hour": [
            "om (\\d+[.,]?\\d*) time",
            "om (\\d+[.,]?\\d*) timer"
        ],
        "in \\1 minute": [
            "om (\\d+[.,]?\\d*) minutt",
            "om (\\d+[.,]?\\d*) minutter"
        ],
        "in \\1 month": [
            "om (\\d+[.,]?\\d*) måned",
            "om (\\d+[.,]?\\d*) måneder"
        ],
        "in \\1 second": [
            "om (\\d+[.,]?\\d*) sekund",
            "om (\\d+[.,]?\\d*) sekunder"
        ],
        "in \\1 week": [
            "om (\\d+[.,]?\\d*) uke",
            "om (\\d+[.,]?\\d*) uker"
        ],
        "in \\1 year": [
            "om (\\d+[.,]?\\d*) år"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
