info = {
    "name": "fil",
    "date_order": "MDY",
    "january": [
        "ene",
        "enero"
    ],
    "february": [
        "peb",
        "pebrero"
    ],
    "march": [
        "mar",
        "marso"
    ],
    "april": [
        "abr",
        "abril"
    ],
    "may": [
        "may",
        "mayo"
    ],
    "june": [
        "hun",
        "hunyo"
    ],
    "july": [
        "hul",
        "hulyo"
    ],
    "august": [
        "ago",
        "agosto"
    ],
    "september": [
        "set",
        "setyembre"
    ],
    "october": [
        "okt",
        "oktubre"
    ],
    "november": [
        "nob",
        "nobyembre"
    ],
    "december": [
        "dis",
        "disyembre"
    ],
    "monday": [
        "lun",
        "lunes"
    ],
    "tuesday": [
        "mar",
        "martes"
    ],
    "wednesday": [
        "miy",
        "miyerkules"
    ],
    "thursday": [
        "huw",
        "huwebes"
    ],
    "friday": [
        "biy",
        "biyernes"
    ],
    "saturday": [
        "sab",
        "sabado"
    ],
    "sunday": [
        "lin",
        "linggo"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "taon"
    ],
    "month": [
        "buwan"
    ],
    "week": [
        "linggo"
    ],
    "day": [
        "araw"
    ],
    "hour": [
        "oras"
    ],
    "minute": [
        "min",
        "minuto"
    ],
    "second": [
        "seg",
        "segundo"
    ],
    "relative-type": {
        "0 day ago": [
            "ngayong araw"
        ],
        "0 hour ago": [
            "ngayong oras"
        ],
        "0 minute ago": [
            "sa minutong ito"
        ],
        "0 month ago": [
            "ngayong buwan"
        ],
        "0 second ago": [
            "ngayon"
        ],
        "0 week ago": [
            "ngayong linggo",
            "sa linggong ito"
        ],
        "0 year ago": [
            "ngayong taon"
        ],
        "1 day ago": [
            "kahapon"
        ],
        "1 month ago": [
            "nakaraang buwan"
        ],
        "1 week ago": [
            "nakalipas na linggo",
            "nakaraang linggo"
        ],
        "1 year ago": [
            "nakaraang taon"
        ],
        "in 1 day": [
            "bukas"
        ],
        "in 1 month": [
            "susunod na buwan"
        ],
        "in 1 week": [
            "susunod na linggo"
        ],
        "in 1 year": [
            "susunod na taon"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) araw ang nakalipas"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) oras ang nakalipas",
            "(\\d+[.,]?\\d*) oras nakalipas"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) min ang nakalipas",
            "(\\d+[.,]?\\d*) minuto ang nakalipas"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) buwan ang nakalipas"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) seg ang nakalipas",
            "(\\d+[.,]?\\d*) seg nakalipas",
            "(\\d+[.,]?\\d*) segundo ang nakalipas"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) linggo ang nakalipas"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) taon ang nakalipas"
        ],
        "in \\1 day": [
            "sa (\\d+[.,]?\\d*) araw"
        ],
        "in \\1 hour": [
            "sa (\\d+[.,]?\\d*) oras"
        ],
        "in \\1 minute": [
            "sa (\\d+[.,]?\\d*) min",
            "sa (\\d+[.,]?\\d*) minuto"
        ],
        "in \\1 month": [
            "sa (\\d+[.,]?\\d*) buwan"
        ],
        "in \\1 second": [
            "sa (\\d+[.,]?\\d*) seg",
            "sa (\\d+[.,]?\\d*) segundo"
        ],
        "in \\1 week": [
            "sa (\\d+[.,]?\\d*) linggo"
        ],
        "in \\1 year": [
            "sa (\\d+[.,]?\\d*) taon"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
